@@ -1,6 +1,6 @@
 from maleo.schemas.resource import Resource, ResourceIdentifier
 
-CLIENT_RESOURCE = Resource(
+PATIENT_RESOURCE = Resource(
     identifiers=[ResourceIdentifier(key="patient", name="Patient", slug="patients")],
     details=None,
 )
